JCCallItemImpl class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setAutoStartAudio(
String itemId, bool isAuto) → Future< bool> -
setDisplayName(
String displayName, String itemId) → Future< bool> -
startOtherVideo(
int mode, String itemId) → Future< JCMediaDeviceVideoCanvas> -
startSelfVideo(
int mode, String itemId) → Future< JCMediaDeviceVideoCanvas> -
stopOtherVideo(
String itemId) → Future< bool> -
stopSelfVideo(
String itemId) → Future< bool>