JcNewPushImpl class

Inheritance

Constructors

JcNewPushImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createNativeJCNewPush(JCClient client, JCNewPushCallback callback) Future<bool>
override
destroyObj() Future<bool>
@internal 销毁对象
override
init(int type, String content) Future<bool>
初始化模版,登录后调用
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uninit() Future<bool>
注销push服务,登出前调用,否则终端还会收到push
override
updateToken(int pushType, String tokenId, String token) Future<int>
上传token,获取对应push平台的token后调用
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

methodTag → const String