JCCallItem class

Constructors

JCCallItem(String _itemId, String? displayName, String? renderId, int direction, bool video, int beginTime, int talkingBeginTime, int state, bool hold, bool held, bool mute, bool speakerMute, bool microphoneMute, bool audioRecord, String? audioRecordFilePath, bool localVideoRecord, String? localVideoRecordFilePath, bool remoteVideoRecord, String? remoteVideoRecordFilePath, bool active, bool uploadVideoStreamSelf, bool uploadVideoStreamOther, int reason, int audioNetSendStatus, int audioNetReceiveStatus, int videoNetSendStatus, int videoNetReceiveStatus, String? serverCallId, String? extraParam, bool otherAudioInterrupt, String? ticket, bool autoStartAudio, String? userDataParam)
JCCallItem.fromJson(Map<String, dynamic> json)
将json转换为JCCallItem对象
factory

Properties

active bool
final
audioNetReceiveStatus int
final
audioNetSendStatus int
final
audioRecord bool
final
audioRecordFilePath String?
final
autoStartAudio bool
final
beginTime int
final
direction int
final
displayName String?
final
extraParam String?
final
hashCode int
The hash code for this object.
no setterinherited
held bool
final
hold bool
final
itemId String
no setter
localVideoRecord bool
final
localVideoRecordFilePath String?
final
microphoneMute bool
final
mute bool
final
otherAudioInterrupt bool
final
reason int
final
remoteVideoRecord bool
final
remoteVideoRecordFilePath String?
final
renderId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverCallId String?
final
speakerMute bool
final
state int
final
talkingBeginTime int
final
ticket String?
final
uploadVideoStreamOther bool
final
uploadVideoStreamSelf bool
final
userDataParam String?
final
video bool
final
videoNetReceiveStatus int
final
videoNetSendStatus int
final

Methods

getActive() bool
获取是否为激活状态
getAudioNetReceiveStatus() int
获得音频接收网络状态
getAudioNetSendStatus() int
获得音频发送网络状态
getAudioRecord() bool
获取此路通话是否为录音状态
getAudioRecordFilePath() String?
获取录音文件的保存路径
getBeginTime() int
获取通话建立时间戳,单位秒
getDirection() int
获取通话方向(呼入或呼出)
getDisplayName() String?
获取用户昵称
getExtraParam() String?
获取自定义参数
getHeld() bool
获取此路通话是否为被挂起状态
getHold() bool
获取此路通话是否为挂起状态
getLocalVideoRecord() bool
返回是否在录制本端视频
getLocalVideoRecordFilePath() String?
获取本端视频录制文件的保存路径
getMicrophoneMute() bool
获取此路通话是否为音频输入静音状态
getMute() bool
获取此路通话是否为音频输入静音状态
getOtherAudioInterrupt() bool
获取对端声音是否中断
getReason() int
获取通话结束原因
getRemoteVideoRecord() bool
返回是否有在录制远端视频
getRemoteVideoRecordFilePath() String?
获取远端视频录制文件的保存路径
getRenderId() String?
获取渲染标识
getServerCallId() String?
获取服务端唯一通话CallId
getSpeakerMute() bool
获取此路通话是否为音频输出静音状态
getState() int
获取通话状态
getTalkingBeginTime() int
获取通话开始时间戳,单位秒
getTicket() String?
获取ticket
getToString() String
获取通话详情
getUploadVideoStreamOther() bool
获取对端是否在上传视频流
getUploadVideoStreamSelf() bool
获取本端是否在上传视频流
getUserDataParam() String?
获取UserDataParam参数
getUserId() String
获取用户标识
getVideo() bool
获取是否为视频通话
getVideoNetReceiveStatus() int
获得视频接收网络状态
getVideoNetSendStatus() int
获得视频发送网络状态
isAutoStartAudio() bool
获取是否要在通话建立时自动startAudio
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAutoStartAudio(bool isAuto) Future<bool>
设置电话接通时是否自动startAudio
setDisplayName(String displayName) Future<bool>
设置通话对方昵称
startOtherVideo(int mode) Future<JCMediaDeviceVideoCanvas>
启动对端视频渲染
startSelfVideo(int mode) Future<JCMediaDeviceVideoCanvas>
启动自身视频渲染
stopOtherVideo() Future<bool>
停止对端视频渲染
stopSelfVideo() Future<bool>
停止自身视频渲染
toString() String
toString
override

Operators

operator ==(Object other) bool
The equality operator.
inherited