JCClientCallback mixin

JCClientCallback 回调,用于回调登录相关事件

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClientStateChange(int state, int oldState) → void
登录状态变化回调
onLogin(bool result, int reason) → void
登录结果回调
onLogout(int reason) → void
登出回调
onOnlineMessageReceive(String userId, String content) → void
收到在线消息
onOnlineMessageSendResult(int operationId, bool result) → void
在线消息发送结果
onServerMessageReceive(String type, String params, String message) → void
收到服务的消息
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited