JCMediaDeviceCamera class

摄像头

Constructors

JCMediaDeviceCamera.fromJson(Map<String, dynamic> json)

Properties

cameraId String?
摄像头id
getter/setter pair
cameraName String?
摄像头名字
getter/setter pair
cameraType int
摄像头类型:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited